@@ -527,6 +527,7 @@ const zend_function_entry php_event_base_ce_functions[] = {/* {{{ */
 	PHP_ME(EventBase, gotExit,            arginfo_event__void,              ZEND_ACC_PUBLIC)
 	PHP_ME(EventBase, getTimeOfDayCached, arginfo_event__void,              ZEND_ACC_PUBLIC)
 	PHP_ME(EventBase, reInit,             arginfo_event__void,              ZEND_ACC_PUBLIC)
+	PHP_ME(EventBase, free,               arginfo_event__void,              ZEND_ACC_PUBLIC)
 #if LIBEVENT_VERSION_NUMBER >= 0x02010100
 	PHP_ME(EventBase, updateCacheTime, arginfo_event__void, ZEND_ACC_PUBLIC)
 #endif
@@ -553,6 +554,7 @@ const zend_function_entry php_event_config_ce_functions[] = {/* {{{ */
 const zend_function_entry php_event_bevent_ce_functions[] = {/* {{{ */
 	PHP_ME(EventBufferEvent, __construct,       arginfo_bufferevent__construct,    ZEND_ACC_PUBLIC  | ZEND_ACC_CTOR)
 	PHP_ME(EventBufferEvent, free,              arginfo_event__void,               ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, close,             arginfo_event__void,               ZEND_ACC_PUBLIC)
 	PHP_ME(EventBufferEvent, connect,           arginfo_bufferevent_connect,       ZEND_ACC_PUBLIC)
 	PHP_ME(EventBufferEvent, connectHost,       arginfo_bufferevent_connecthost,   ZEND_ACC_PUBLIC)
 	PHP_ME(EventBufferEvent, getDnsErrorString, arginfo_event__void,               ZEND_ACC_PUBLIC)
@@ -571,10 +573,14 @@ const zend_function_entry php_event_bevent_ce_functions[] = {/* {{{ */
 	PHP_ME(EventBufferEvent, setPriority,       arginfo_bufferevent_priority_set,  ZEND_ACC_PUBLIC)
 	PHP_ME(EventBufferEvent, setTimeouts,       arginfo_bufferevent_set_timeouts,  ZEND_ACC_PUBLIC)
 #ifdef HAVE_EVENT_OPENSSL_LIB
-	PHP_ME(EventBufferEvent, sslFilter,      arginfo_bufferevent_ssl_filter, ZEND_ACC_PUBLIC  | ZEND_ACC_STATIC)
-	PHP_ME(EventBufferEvent, sslSocket,      arginfo_bufferevent_ssl_socket, ZEND_ACC_PUBLIC  | ZEND_ACC_STATIC)
-	PHP_ME(EventBufferEvent, sslError,       arginfo_event__void,            ZEND_ACC_PUBLIC)
-	PHP_ME(EventBufferEvent, sslRenegotiate, arginfo_event__void,            ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, sslFilter,           arginfo_bufferevent_ssl_filter, ZEND_ACC_PUBLIC  | ZEND_ACC_STATIC)
+	PHP_ME(EventBufferEvent, sslSocket,           arginfo_bufferevent_ssl_socket, ZEND_ACC_PUBLIC  | ZEND_ACC_STATIC)
+	PHP_ME(EventBufferEvent, sslError,            arginfo_event__void,            ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, sslRenegotiate,      arginfo_event__void,            ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, sslGetCipherInfo,    arginfo_event__void,            ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, sslGetCipherName,    arginfo_event__void,            ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, sslGetCipherVersion, arginfo_event__void,            ZEND_ACC_PUBLIC)
+	PHP_ME(EventBufferEvent, sslGetProtocol,      arginfo_event__void,            ZEND_ACC_PUBLIC)
 #endif
 
 	PHP_FE_END
